@@ -140,6 +140,7 @@ struct _NiceAgent
   NiceProxyType proxy_type;       /* property: Proxy type */
   gchar *proxy_username;          /* property: Proxy username */
   gchar *proxy_password;          /* property: Proxy password */
+  GHashTable *proxy_extra_headers;/* property: Proxy extra headers */
   gboolean saved_controlling_mode;/* property: controlling-mode */
   guint timer_ta;                 /* property: timer Ta */
   guint max_conn_checks;          /* property: max connectivity checks */
@@ -181,6 +182,9 @@ struct _NiceAgent
   gboolean bytestream_tcp;         /* property: bytestream-tcp */
   gboolean keepalive_conncheck;    /* property: keepalive_conncheck */
 
+  GCancellable *stun_resolving_cancellable; /* Cancel STUN name resolution */
+  GSList *stun_resolving_list;     /* List of ongoing resolutions */
+
   GQueue pending_signals;
   gboolean use_ice_udp;
   gboolean use_ice_tcp;
