@@ -131,7 +131,7 @@ discovery_add_relay_candidate (
   TurnServer *turn,
   uint32_t *lifetime);
 
-NiceCandidate*
+void
 discovery_add_server_reflexive_candidate (
   NiceAgent *agent,
   guint stream_id,
@@ -139,6 +139,7 @@ discovery_add_server_reflexive_candidate (
   NiceAddress *address,
   NiceCandidateTransport transport,
   NiceSocket *base_socket,
+  const NiceAddress *server_address,
   gboolean nat_assisted);
 
 void
@@ -147,7 +148,8 @@ discovery_discover_tcp_server_reflexive_candidates (
   guint stream_id,
   guint component_id,
   NiceAddress *address,
-  NiceSocket *base_socket);
+  NiceSocket *base_socket,
+  const NiceAddress *server_address);
 
 NiceCandidate*
 discovery_add_peer_reflexive_candidate (
