@@ -81,6 +81,7 @@ static gboolean socket_is_reliable (NiceSocket *sock);
 static gboolean socket_can_send (NiceSocket *sock, NiceAddress *addr);
 static void socket_set_writable_callback (NiceSocket *sock,
     NiceSocketWritableCb callback, gpointer user_data);
+static gboolean socket_is_based_on (NiceSocket *sock, NiceSocket *other);
 
 
 NiceSocket *
@@ -108,6 +109,7 @@ nice_socks5_socket_new (NiceSocket *base_socket,
     sock->is_reliable = socket_is_reliable;
     sock->can_send = socket_can_send;
     sock->set_writable_callback = socket_set_writable_callback;
+    sock->is_based_on = socket_is_based_on;
     sock->close = socket_close;
 
     /* Send SOCKS5 handshake */
@@ -167,9 +169,8 @@ socket_recv_messages (NiceSocket *sock,
   guint i;
   gint ret = -1;
 
-  /* Socket has been closed: */
-  if (sock->priv == NULL)
-    return 0;
+  /* Make sure socket has not been freed: */
+  g_assert (sock->priv != NULL);
 
   switch (priv->state) {
     case SOCKS_STATE_CONNECTED:
@@ -423,9 +424,8 @@ socket_send_messages (NiceSocket *sock, const NiceAddress *to,
 {
   Socks5Priv *priv = sock->priv;
 
-  /* Socket has been closed: */
-  if (sock->priv == NULL)
-    return -1;
+  /* Make sure socket has not been freed: */
+  g_assert (sock->priv != NULL);
 
   if (priv->state == SOCKS_STATE_CONNECTED) {
     /* Fast path: pass through to the base socket once connected. */
@@ -488,3 +488,12 @@ socket_set_writable_callback (NiceSocket *sock,
 
   nice_socket_set_writable_callback (priv->base_socket, callback, user_data);
 }
+
+static gboolean
+socket_is_based_on (NiceSocket *sock, NiceSocket *other)
+{
+  Socks5Priv *priv = sock->priv;
+
+  return (sock == other) ||
+      (priv && nice_socket_is_based_on (priv->base_socket, other));
+}
