@@ -1,9 +1,9 @@
 /*
  * This file is part of the Nice GLib ICE library.
  *
- * (C) 2008 Collabora Ltd.
- * (C) 2008 Nokia Corporation. All rights reserved.
+ * (C) 2008-2009 Collabora Ltd.
  *  Contact: Youness Alaoui
+ * (C) 2008-2009 Nokia Corporation. All rights reserved.
  *
  * The contents of this file are subject to the Mozilla Public License Version
  * 1.1 (the "License"); you may not use this file except in compliance with
@@ -20,6 +20,8 @@
  * The Initial Developers of the Original Code are Collabora Ltd and Nokia
  * Corporation. All Rights Reserved.
  *
+ * Contributors:
+ *   Youness Alaoui, Collabora Ltd.
  *
  * Alternatively, the contents of this file may be used under the terms of the
  * the GNU Lesser General Public License Version 2.1 (the "LGPL"), in which
@@ -55,10 +57,9 @@
 #include "win32_common.h"
 #else
 #include <stdint.h>
-#include <stdbool.h>
 #endif
 
-
+#include <stdbool.h>
 #include <sys/types.h>
 
 /**
@@ -71,24 +72,37 @@ typedef struct stun_agent_t StunAgent;
 #include "stunmessage.h"
 #include "debug.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /**
  * StunCompatibility:
  * @STUN_COMPATIBILITY_RFC3489: Use the STUN specifications compatible with
  * RFC 3489
  * @STUN_COMPATIBILITY_RFC5389: Use the STUN specifications compatible with
  * RFC 5389
- * @STUN_COMPATIBILITY_WLM2009: Use the STUN specifications compatible with
- * Windows Live Messenger 2009 (a mix between RFC3489 and RFC5389, as well as
- * a special usecase against a typo in their code)
+ * @STUN_COMPATIBILITY_MSICE2: Use the STUN specifications compatible with
+ * [MS-ICE2] (a mix between RFC3489 and RFC5389)
+ * @STUN_COMPATIBILITY_OC2007: Use the STUN specifications compatible with
+ * Microsoft Office Communicator 2007 (basically RFC3489 with swapped
+ * REALM and NONCE attribute hex IDs, attributes are not aligned)
+ * @STUN_COMPATIBILITY_WLM2009: An alias for @STUN_COMPATIBILITY_MSICE2
  * @STUN_COMPATIBILITY_LAST: Dummy last compatibility mode
  *
  * Enum that specifies the STUN compatibility mode of the #StunAgent
+ *
+ * <warning>@STUN_COMPATIBILITY_WLM2009 is deprecated and should not be used
+ * in newly-written code. It is kept for compatibility reasons and represents
+ * the same compatibility as @STUN_COMPATIBILITY_MSICE2.</warning>
  */
 typedef enum {
   STUN_COMPATIBILITY_RFC3489,
   STUN_COMPATIBILITY_RFC5389,
-  STUN_COMPATIBILITY_WLM2009,
-  STUN_COMPATIBILITY_LAST = STUN_COMPATIBILITY_WLM2009
+  STUN_COMPATIBILITY_MSICE2,
+  STUN_COMPATIBILITY_OC2007,
+  STUN_COMPATIBILITY_WLM2009 = STUN_COMPATIBILITY_MSICE2,
+  STUN_COMPATIBILITY_LAST = STUN_COMPATIBILITY_OC2007
 } StunCompatibility;
 
 
@@ -113,6 +127,9 @@ typedef enum {
  * @STUN_VALIDATION_UNKNOWN_ATTRIBUTE: The message is valid but contains one
  * or more unknown comprehension attributes. This is a response, or error,
  * or indication message and no error response should be sent
+ * @STUN_VALIDATION_FORBIDDEN: The message response is valid and indicates
+ * the peer responded with the error code 403 'Forbidden'.  No response
+ * should be sent.
  *
  * This enum is used as the return value of stun_agent_validate() and represents
  * the status result of the validation of a STUN message.
@@ -127,6 +144,7 @@ typedef enum {
   STUN_VALIDATION_UNMATCHED_RESPONSE,
   STUN_VALIDATION_UNKNOWN_REQUEST_ATTRIBUTE,
   STUN_VALIDATION_UNKNOWN_ATTRIBUTE,
+  STUN_VALIDATION_FORBIDDEN,
 } StunValidationStatus;
 
 /**
@@ -141,7 +159,7 @@ typedef enum {
  * to the STUN messages it creates. Calling nice_agent_set_software() will have
  * the same effect as enabling this Usage. STUN Indications do not have the
  * SOFTWARE attributes added to them though. The SOFTWARE attribute is only
- * added for the RFC5389 and WLM2009 compatibility modes.
+ * added for the RFC5389 and MSICE2 compatibility modes.
  * @STUN_AGENT_USAGE_IGNORE_CREDENTIALS: The agent should ignore any credentials
  * in the STUN messages it receives (the MESSAGE-INTEGRITY attribute
  * will never be validated by stun_agent_validate())
@@ -155,6 +173,12 @@ typedef enum {
  * should be (a response to a previously created request). This means that the
  * #StunMessageIntegrityValidate callback will always be called when there is
  * a MESSAGE-INTEGRITY attribute.
+ * @STUN_AGENT_USAGE_NO_ALIGNED_ATTRIBUTES: The agent should not assume STUN
+ * attributes are aligned on 32-bit boundaries when parsing messages and also
+ * do not add padding when creating messages.
+ * @STUN_AGENT_USAGE_CONSENT_FRESHNESS: The agent should expect and use
+ * the %STUN_VALIDATION_FORBIDDEN return value from ERROR-CODE responses and
+ * abort all transactions accordingly.
  *
  * This enum defines a bitflag usages for a #StunAgent and they will define how
  * the agent should behave, independently of the compatibility mode it uses.
@@ -169,6 +193,8 @@ typedef enum {
   STUN_AGENT_USAGE_IGNORE_CREDENTIALS        = (1 << 4),
   STUN_AGENT_USAGE_NO_INDICATION_AUTH        = (1 << 5),
   STUN_AGENT_USAGE_FORCE_VALIDATER           = (1 << 6),
+  STUN_AGENT_USAGE_NO_ALIGNED_ATTRIBUTES     = (1 << 7),
+  STUN_AGENT_USAGE_CONSENT_FRESHNESS         = (1 << 8),
 } StunAgentUsageFlags;
 
 
@@ -188,6 +214,7 @@ struct stun_agent_t {
   uint16_t *known_attributes;
   StunAgentUsageFlags usage_flags;
   const char *software_attribute;
+  bool ms_ice2_send_legacy_connchecks;
 };
 
 /**
@@ -286,7 +313,7 @@ bool stun_agent_default_validater (StunAgent *agent,
     <para>
     The #STUN_AGENT_USAGE_USE_FINGERPRINT and #STUN_AGENT_USAGE_ADD_SOFTWARE
     usage flags are only valid if the #STUN_COMPATIBILITY_RFC5389 or
-    #STUN_COMPATIBILITY_WLM2009 @compatibility is used
+    #STUN_COMPATIBILITY_MSICE2 @compatibility is used
     </para>
  </note>
  */
@@ -469,6 +496,7 @@ size_t stun_agent_finish_message (StunAgent *agent, StunMessage *msg,
  * this will allow the #StunAgent to forget about the timed out transaction and
  * free its slot for future transactions.
  * </para>
+ * Since: 0.0.6
  * Returns: %TRUE if the transaction was found, %FALSE otherwise
  */
 bool stun_agent_forget_transaction (StunAgent *agent, StunTransactionId id);
@@ -483,7 +511,8 @@ bool stun_agent_forget_transaction (StunAgent *agent, StunTransactionId id);
  * STUN requests, responses and error responses.
  * <para>
  * Calling this function will automatically enable the addition of the SOFTWARE
- * attribute for RFC5389 and WLM2009 compatibility modes.
+ * attribute for RFC5389 and MSICE2 compatibility modes.
+ *
  * </para>
  * <note>
      <para>
@@ -496,7 +525,13 @@ bool stun_agent_forget_transaction (StunAgent *agent, StunTransactionId id);
      </para>
    </note>
  *
+ * Since: 0.0.10
+ *
  */
 void stun_agent_set_software (StunAgent *agent, const char *software);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _STUN_AGENT_H */
