@@ -54,7 +54,7 @@
 #include <sys/types.h>
 
 #ifdef _WIN32
-#include <WinSock2.h>
+#include <winsock2.h>
 #else
 #include <sys/socket.h>
 #include <netdb.h>
