@@ -119,7 +119,7 @@ write_to_sock (PseudoTcpSocket *sock)
     len = fread (buf, 1, sizeof(buf), in);
     if (len == 0) {
       g_debug ("Done reading data from file");
-      g_assert (feof (in));
+      g_assert_true (feof (in));
       reading_done = TRUE;
       pseudo_tcp_socket_close (sock, FALSE);
       break;
@@ -131,7 +131,7 @@ write_to_sock (PseudoTcpSocket *sock)
       if (wlen < (gint) len) {
         g_debug ("seeking  %" G_GSIZE_FORMAT " from %lu", wlen - len, ftell (in));
         fseek (in, wlen - len, SEEK_CUR);
-        g_assert (!feof (in));
+        g_assert_true (!feof (in));
         g_debug ("Socket queue full after %d bytes written", total);
         break;
       }
@@ -173,10 +173,10 @@ readable (PseudoTcpSocket *sock, gpointer data)
         else {
           total_wrote += len;
 
-          g_assert (total_wrote <= total_read);
+          g_assert_cmpint (total_wrote, <=, total_read);
           g_debug ("Written %d bytes, need %d bytes", total_wrote, total_read);
           if (total_wrote == total_read && feof (in)) {
-            g_assert (reading_done);
+            g_assert_true (reading_done);
             pseudo_tcp_socket_close (sock, FALSE);
           }
         }
