@@ -52,7 +52,7 @@ static gboolean
 on_server_connection_available (gpointer user_data)
 {
   server = nice_tcp_passive_socket_accept (passive_sock);
-  g_assert (server);
+  g_assert_true (server);
 
   g_main_loop_quit (mainloop);
 
@@ -63,7 +63,7 @@ static gboolean
 on_server_input_available (gpointer user_data)
 {
   g_assert_cmpint (5, ==, nice_socket_recv (server, &tmp, 5, buf));
-  g_assert (nice_address_equal (&tmp, &client->addr));
+  g_assert_true (nice_address_equal (&tmp, &client->addr));
 
   g_main_loop_quit (mainloop);
 
@@ -74,7 +74,7 @@ static gboolean
 on_client_input_available (gpointer user_data)
 {
   g_assert_cmpint (5, ==, nice_socket_recv (client, &tmp, 5, buf));
-  g_assert (nice_address_equal (&tmp, &server->addr));
+  g_assert_true (nice_address_equal (&tmp, &server->addr));
 
   g_main_loop_quit (mainloop);
 
@@ -93,10 +93,10 @@ main (void)
   mainloop = g_main_loop_new (NULL, FALSE);
 
   nice_address_init (&active_bind_addr);
-  g_assert (nice_address_set_from_string (&active_bind_addr, "::1"));
+  g_assert_true (nice_address_set_from_string (&active_bind_addr, "127.0.0.1"));
 
   nice_address_init (&passive_bind_addr);
-  g_assert (nice_address_set_from_string (&passive_bind_addr, "127.0.0.1"));
+  g_assert_true (nice_address_set_from_string (&passive_bind_addr, "127.0.0.1"));
   nice_address_set_port (&passive_bind_addr, 0);
 
   nice_address_init (&tmp);
@@ -104,7 +104,7 @@ main (void)
   passive_sock = nice_tcp_passive_socket_new (g_main_loop_get_context (mainloop),
       &passive_bind_addr, &error);
   g_assert_no_error (error);
-  g_assert (passive_sock);
+  g_assert_true (passive_sock);
 
   srv_listen_source = g_socket_create_source (passive_sock->fileno,
       G_IO_IN, NULL);
@@ -114,15 +114,15 @@ main (void)
 
   active_sock = nice_tcp_active_socket_new (g_main_loop_get_context (mainloop),
       &active_bind_addr);
-  g_assert (active_sock);
+  g_assert_true (active_sock);
 
   client = nice_tcp_active_socket_connect (active_sock, &passive_sock->addr);
-  g_assert (client);
+  g_assert_true (client);
   nice_socket_free (active_sock);
   active_sock = NULL;
 
   g_main_loop_run (mainloop); /* -> on_server_connection_available */
-  g_assert (server);
+  g_assert_true (server);
 
   srv_input_source = g_socket_create_source (server->fileno, G_IO_IN, NULL);
   g_source_set_callback (srv_input_source,
@@ -134,20 +134,20 @@ main (void)
       on_client_input_available, NULL, NULL);
   g_source_attach (cli_input_source, g_main_loop_get_context (mainloop));
 
-  g_assert (nice_address_get_port (&client->addr) != 0);
+  g_assert_true (nice_address_get_port (&client->addr) != 0);
 
-  g_assert (nice_address_set_from_string (&tmp, "127.0.0.1"));
+  g_assert_true (nice_address_set_from_string (&tmp, "127.0.0.1"));
   nice_address_set_port (&tmp, nice_address_get_port (&server->addr));
-  g_assert (nice_address_get_port (&tmp) != 0);
+  g_assert_true (nice_address_get_port (&tmp) != 0);
 
 
   g_assert_cmpint (5, ==, nice_socket_send (client, &tmp, 5, "hello"));
   g_main_loop_run (mainloop); /* -> on_server_input_available */
-  g_assert (0 == strncmp (buf, "hello", 5));
+  g_assert_true (0 == strncmp (buf, "hello", 5));
 
   g_assert_cmpint (5, ==, nice_socket_send (server, &tmp, 5, "uryyb"));
   g_main_loop_run (mainloop); /* -> on_client_input_available */
-  g_assert (0 == strncmp (buf, "uryyb", 5));
+  g_assert_true (0 == strncmp (buf, "uryyb", 5));
 
   nice_socket_free (client);
   nice_socket_free (server);
